@@ -28,7 +28,11 @@ check_sphericity <- function(x, ...) {
 
 #' @export
 check_sphericity.default <- function(x, ...) {
-  insight::format_error(paste0("Test not supported yet for object of class `", class(x)[1], "`."))
+  insight::format_error(paste0(
+    "Test not supported yet for object of class `",
+    class(x)[1],
+    "`."
+  ))
 }
 
 
@@ -36,7 +40,9 @@ check_sphericity.default <- function(x, ...) {
 
 #' @export
 plot.check_sphericity <- function(x, ...) {
-  insight::format_warning("There is currently no `plot()` method for `check_sphericity()`.")
+  insight::format_warning(
+    "There is currently no `plot()` method for `check_sphericity()`."
+  )
 }
 
 
@@ -78,7 +84,9 @@ check_sphericity.Anova.mlm <- function(x, ...) {
 #' @export
 check_sphericity.afex_aov <- function(x, ...) {
   if (length(attr(x, "within")) == 0) {
-    insight::format_error("Mauchly Test of Sphericity is only aplicable to ANOVAs with within-subjects factors.")
+    insight::format_error(
+      "Mauchly Test of Sphericity is only aplicable to ANOVAs with within-subjects factors."
+    )
   }
 
   check_sphericity.Anova.mlm(x, ...)
