@@ -93,7 +93,10 @@ r2.default <- function(model, ci = NULL, verbose = TRUE, ...) {
   )
 
   if (is.null(out) && isTRUE(verbose)) {
-    insight::print_color(sprintf("`r2()` does not support models of class `%s`.\n", class(model)[1]), "red")
+    insight::print_color(
+      sprintf("`r2()` does not support models of class `%s`.\n", class(model)[1]),
+      "red"
+    )
   }
 
   if (!is.null(out)) {
@@ -210,7 +213,8 @@ r2.cph <- r2.ols
 r2.mhurdle <- function(model, ...) {
   resp <- insight::get_response(model, verbose = FALSE)
   mean_resp <- mean(resp, na.rm = TRUE)
-  ftd <- model$fitted.values[, "pos", drop = TRUE] * (1 - model$fitted.values[, "zero", drop = TRUE])
+  ftd <- model$fitted.values[, "pos", drop = TRUE] *
+    (1 - model$fitted.values[, "zero", drop = TRUE])
   n <- length(resp)
   K <- insight::n_parameters(model)
   Ko <- length(model$naive$coefficients)
@@ -296,7 +300,9 @@ r2.glm <- function(model, ci = NULL, verbose = TRUE, ...) {
     class(out) <- c("r2_pseudo", class(out))
   } else if (info$is_binomial && !info$is_bernoulli && class(model)[1] == "glm") {
     if (verbose) {
-      insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
+      insight::format_warning(
+        "Can't calculate accurate R2 for binomial models that are not Bernoulli models."
+      )
     }
     out <- NULL
   } else if (info$is_orderedbeta) {
@@ -327,10 +333,8 @@ r2.nestedLogit <- function(model, ci = NULL, verbose = TRUE, ...) {
 }
 
 
-
 # mfx models ---------------------
 
-
 #' @export
 r2.logitmfx <- function(model, ...) {
   r2(model$fit, ...)
@@ -364,11 +368,8 @@ r2.betaor <- r2.logitmfx
 r2.model_fit <- r2.logitmfx
 
 
-
-
 # Cox & Snell R2 ---------------------
 
-
 #' @export
 r2.BBreg <- function(model, ...) {
   out <- list(R2_CoxSnell = r2_coxsnell(model))
@@ -384,11 +385,8 @@ r2.crch <- r2.BBreg
 r2.bayesx <- r2.BBreg
 
 
-
-
 # Nagelkerke R2 ----------------------
 
-
 #' @export
 r2.censReg <- function(model, ...) {
   out <- list(R2_Nagelkerke = r2_nagelkerke(model))
@@ -441,12 +439,8 @@ r2.mblogit <- function(model, ...) {
 }
 
 
-
-
-
 # McFadden ----------------------
 
-
 #' @export
 r2.multinom <- function(model, ...) {
   out <- r2_mcfadden(model)
@@ -458,11 +452,8 @@ r2.multinom <- function(model, ...) {
 r2.mlogit <- r2.multinom
 
 
-
-
 # Zeroinflated R2 ------------------
 
-
 #' @export
 r2.hurdle <- function(model, ...) {
   r2_zeroinflated(model)
@@ -477,7 +468,6 @@ r2.zeroinfl <- r2.hurdle
 
 # Nakagawa R2 ----------------------
 
-
 #' @rdname r2
 #' @export
 r2.merMod <- function(model, ci = NULL, tolerance = 1e-5, ...) {
@@ -516,6 +506,7 @@ r2.glmmTMB <- function(model, ci = NULL, tolerance = 1e-5, verbose = TRUE, ...)
     }
     # calculate r2 for non-mixed glmmTMB models here -------------------------
     info <- insight::model_info(model, verbose = FALSE)
+    matrix_response <- grepl("cbind", insight::find_response(model), fixed = TRUE)
 
     if (info$is_linear) {
       # for linear models, use the manual calculation
@@ -526,10 +517,25 @@ r2.glmmTMB <- function(model, ci = NULL, tolerance = 1e-5, verbose = TRUE, ...)
       attr(out, "model_type") <- "Logistic"
       names(out$R2_Tjur) <- "Tjur's R2"
       class(out) <- c("r2_pseudo", class(out))
+    } else if (info$is_betabinomial) {
+      # currently, beta-binomial models without proportion response are not supported
+      if (matrix_response) {
+        if (verbose) {
+          insight::format_warning(
+            "Can't calculate accurate R2 for beta-binomial models with matrix-response formulation."
+          )
+        }
+        out <- NULL
+      } else {
+        # betabinomial default to mcfadden, see pscl:::pR2Work
+        out <- r2_mcfadden(model)
+      }
     } else if (info$is_binomial && !info$is_bernoulli) {
       # currently, non-bernoulli binomial models are not supported
       if (verbose) {
-        insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
+        insight::format_warning(
+          "Can't calculate accurate R2 for binomial models that are not Bernoulli models."
+        )
       }
       out <- NULL
     } else if ((info$is_poisson && !info$is_zero_inflated) || info$is_exponential) {
@@ -586,7 +592,6 @@ r2.wbm <- function(model, tolerance = 1e-5, ...) {
 }
 
 
-
 #' @export
 r2.sem <- function(model, ...) {
   r2_conditional <- model$r2c
@@ -605,10 +610,8 @@ r2.sem <- function(model, ...) {
 }
 
 
-
 # Bayes R2 ------------------------
 
-
 #' @export
 r2.brmsfit <- function(model, ...) {
   r2_bayes(model, ...)
@@ -624,7 +627,6 @@ r2.BFBayesFactor <- r2.brmsfit
 
 # Other methods ------------------------------
 
-
 #' @export
 r2.gam <- function(model, ...) {
   # gamlss inherits from gam, and summary.gamlss prints results automatically
@@ -664,7 +666,6 @@ r2.rma <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.feis <- function(model, ...) {
   out <- list(
@@ -677,26 +678,31 @@ r2.feis <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.fixest <- function(model, ...) {
   insight::check_if_installed("fixest")
 
   r2 <- fixest::r2(model)
 
-  out_normal <- insight::compact_list(list(
-    R2 = r2["r2"],
-    R2_adjusted = r2["ar2"],
-    R2_within = r2["wr2"],
-    R2_within_adjusted = r2["war2"]
-  ), remove_na = TRUE)
+  out_normal <- insight::compact_list(
+    list(
+      R2 = r2["r2"],
+      R2_adjusted = r2["ar2"],
+      R2_within = r2["wr2"],
+      R2_within_adjusted = r2["war2"]
+    ),
+    remove_na = TRUE
+  )
 
-  out_pseudo <- insight::compact_list(list(
-    R2 = r2["pr2"],
-    R2_adjusted = r2["apr2"],
-    R2_within = r2["wpr2"],
-    R2_within_adjusted = r2["wapr2"]
-  ), remove_na = TRUE)
+  out_pseudo <- insight::compact_list(
+    list(
+      R2 = r2["pr2"],
+      R2_adjusted = r2["apr2"],
+      R2_within = r2["wpr2"],
+      R2_within_adjusted = r2["wapr2"]
+    ),
+    remove_na = TRUE
+  )
 
   if (length(out_normal)) {
     out <- out_normal
@@ -708,12 +714,18 @@ r2.fixest <- function(model, ...) {
   structure(class = "r2_generic", out)
 }
 
+
 #' @export
 r2.fixest_multi <- function(model, ...) {
   lapply(model, r2.fixest)
 }
 
 
+#' @export
+r2.oohbchoice <- function(model, ...) {
+  NULL
+}
+
 
 #' @export
 r2.felm <- function(model, ...) {
@@ -728,8 +740,6 @@ r2.felm <- function(model, ...) {
 }
 
 
-
-
 #' @export
 r2.iv_robust <- function(model, ...) {
   out <- list(
@@ -742,7 +752,6 @@ r2.iv_robust <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.ivreg <- function(model, ...) {
   model_summary <- summary(model)
@@ -756,7 +765,6 @@ r2.ivreg <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.bigglm <- function(model, ...) {
   out <- list(R2_CoxSnell = summary(model)$rsq)
@@ -766,7 +774,6 @@ r2.bigglm <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.biglm <- function(model, ...) {
   df.int <- as.numeric(insight::has_intercept(model))
@@ -788,7 +795,6 @@ r2.biglm <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.lmrob <- function(model, ...) {
   model_summary <- summary(model)
@@ -805,7 +811,6 @@ r2.lmrob <- function(model, ...) {
 r2.complmrob <- r2.lmrob
 
 
-
 #' @export
 r2.mmclogit <- function(model, ...) {
   list(R2 = NA)
@@ -815,14 +820,15 @@ r2.mmclogit <- function(model, ...) {
 #' @export
 r2.Arima <- function(model, ...) {
   if (requireNamespace("forecast", quietly = TRUE)) {
-    list(R2 = stats::cor(stats::fitted(model), insight::get_data(model, verbose = FALSE))^2)
+    list(
+      R2 = stats::cor(stats::fitted(model), insight::get_data(model, verbose = FALSE))^2
+    )
   } else {
     list(R2 = NA)
   }
 }
 
 
-
 #' @export
 r2.plm <- function(model, ...) {
   model_summary <- summary(model)
@@ -836,7 +842,6 @@ r2.plm <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.selection <- function(model, ...) {
   model_summary <- summary(model)
@@ -853,7 +858,6 @@ r2.selection <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.svyglm <- function(model, ...) {
   rsq <- (model$null.deviance - model$deviance) / model$null.deviance
@@ -869,7 +873,6 @@ r2.svyglm <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.vglm <- function(model, ...) {
   out <- list(R2_McKelvey = r2_mckelvey(model))
@@ -882,7 +885,6 @@ r2.vglm <- function(model, ...) {
 r2.vgam <- r2.vglm
 
 
-
 #' @export
 r2.DirichletRegModel <- function(model, ...) {
   out <- list(R2_Nagelkerke = r2_nagelkerke(model))
@@ -892,16 +894,27 @@ r2.DirichletRegModel <- function(model, ...) {
 }
 
 
-
-
-
 # helper -------------------
 
-.check_r2_ci_args <- function(ci = NULL, ci_method = "bootstrap", valid_ci_method = NULL, verbose = TRUE) {
-  if (!is.null(ci) && !is.na(ci) && !is.null(valid_ci_method) && !ci_method %in% valid_ci_method) {
+.check_r2_ci_args <- function(
+  ci = NULL,
+  ci_method = "bootstrap",
+  valid_ci_method = NULL,
+  verbose = TRUE
+) {
+  if (
+    !is.null(ci) &&
+      !is.na(ci) &&
+      !is.null(valid_ci_method) &&
+      !ci_method %in% valid_ci_method
+  ) {
     if (verbose) {
       insight::format_warning(
-        paste0("Method `", ci_method, "` to compute confidence intervals for R2 not supported.")
+        paste0(
+          "Method `",
+          ci_method,
+          "` to compute confidence intervals for R2 not supported."
+        )
       )
     }
     return(NULL)
